Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SEAssets ¶
type SEAssets interface {
// FS returns a filesystem containing the assets associated with the service
// extension.
FS() (fs.FS, error)
// ReadFile returns the file contents of a file from the service extension
// assets.
ReadFile(string) ([]byte, error)
}
SEAssets provides behaviors to interact with asset files that have been loaded into a config bundle. These behaviors only work if Orchestrator config is bundled via remote configuration. If the config files are on the local filesystem, then we should interact with those directly instead of using this interface.
Click to show internal directories.
Click to hide internal directories.